@@ -1,9 +1,9 @@
 /* getline.c --- Implementation of replacement getline function.
-   Copyright (C) 2005, 2006 Free Software Foundation, Inc.
+   Copyright (C) 2005, 2006, 2007 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2, or (at
+   published by the Free Software Foundation; either version 3, or (at
    your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -20,8 +20,7 @@
 
 #include <config.h>
 
-#include "getdelim.h"
-#include "getline.h"
+#include <stdio.h>
 
 ssize_t
 getline (char **lineptr, size_t *n, FILE *stream)
